@@ -19,6 +19,7 @@ import warnings
 
 import numpy as np
 import pandas as pd
+import psutil
 import rich
 from rich.console import Console
 
@@ -520,8 +521,7 @@ def calculate_distance_matrix(file, n_trees, output_file):
         pckl = open("Trees.pckl", "wb")
         pickle.dump(trees, pckl)
         pckl.close()
-
-        with mp.Pool() as pool:
+        with mp.Pool(psutil.Process().cpu_affinity()) as pool:
             arg_pool = list(range(len(trees)))
             results = list(pool.imap(func_pool, arg_pool))
         distance_matrix_upper = list(
