@@ -38,7 +38,6 @@ import warnings
 import numpy as np
 import pandas as pd
 from rich import print
-
 # ? rich is a very nice library that allows to
 # ? easily format the output of console
 # ? https://github.com/Textualize/rich
@@ -64,6 +63,13 @@ try:
 except:
     sys.exit("Error")
 
+# silencing some warnings
+from scipy.sparse import SparseEfficiencyWarning
+
+warnings.filterwarnings("ignore", category=DeprecationWarning)
+warnings.filterwarnings("ignore", category=UserWarning)
+warnings.filterwarnings("ignore", category=SparseEfficiencyWarning)
+
 
 # ────────────────────────────────────────────────────────── TREE_SET CLASS ─────
 class tree_set:
@@ -193,7 +199,7 @@ class tree_set:
         with self.console.status("[bold green]Embedding distances...") as status:
             embedding = methods[method](
                 self.distance_matrix,
-                dimensions,
+                dim,
                 self.metadata,
                 quality=quality if not report else True,
                 report=report,
@@ -216,6 +222,7 @@ class tree_set:
             self.embedding_pca = embedding
             self.embedding_pca3D = embedding[:, :4]
             self.embedding_pca2D = embedding[:, :3]
+
         elif method == "tsne":
             if dimensions > 3:
                 warnings.warn(
@@ -224,6 +231,7 @@ class tree_set:
             self.embedding_tsne = embedding
             self.embedding_tsne3D = embedding[:, :4]
             self.embedding_tsne2D = embedding[:, :3]
+
         elif method == "isomap":
             if dimensions > 3:
                 warnings.warn(
@@ -398,6 +406,7 @@ class tree_set:
                 plot_set,
                 select,
                 same_scale,
+                z_axis,
             )
 
         elif method == "tsne":
@@ -416,6 +425,7 @@ class tree_set:
                 plot_set,
                 select,
                 same_scale,
+                z_axis,
             )
 
         elif method == "isomap":
@@ -434,6 +444,7 @@ class tree_set:
                 plot_set,
                 select,
                 same_scale,
+                z_axis,
             )
 
         elif method == "lle":
@@ -452,6 +463,7 @@ class tree_set:
                 plot_set,
                 select,
                 same_scale,
+                z_axis,
             )
 
         else:
@@ -612,10 +624,9 @@ class set_collection(tree_set):
                         sys.exit(
                             f"Set collection can be initialized only with set_collection, tree_set, or file path elements"
                         )
-            for i in remove:
+            for i in remove[::-1]:
                 collection.pop(i)
-            
-            print(collection, remove)
+
             self.collection = collection
             with open(self.file, "w") as trees:
                 for set in collection:
@@ -692,7 +703,7 @@ class set_collection(tree_set):
                         only with another set_collection, a tree_set,\
                             or a list of tree_set"
                         )
-            for i in remove:
+            for i in remove[::-1]:
                 other.pop(i)
 
             return set_collection(self.collection + other)
@@ -752,7 +763,7 @@ class set_collection(tree_set):
                         only with another set_collection, a tree_set,\
                             or a list of tree_set"
                         )
-            for i in remove:
+            for i in remove[::-1]:
                 other.pop(i)
 
             return set_collection(self.collection + other)
